==> php81-nextcloud-28.0.6.tgz: share/nextcloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "File could not be found" : "Faili ei leitud",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Laadi alla",
    "Delete" : "Kustuta",
    "Tags" : "Sildid",
    "Show list view" : "Näita loendivaadet",
    "Home" : "Kodu",
    "Close" : "Sulge",
    "Could not create folder \"{dir}\"" : "Kausta \"{dir}\" loomine ebaõnnestus",
    "This will stop your current uploads." : "See peatab praegused üleslaadimised.",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "Processing files …" : "Failide töötlemine …",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Target folder \"{dir}\" does not exist any more" : "Kausta \"{dir}\" pole enam olemas",
    "Not enough free space" : "Pole piisavalt vaba ruumi",
    "An unknown error has occurred" : "Tekkis tundmatu tõrge",
    "File could not be uploaded" : "Faili üleslaadimine ebaõnnestus",
    "Uploading …" : "Üleslaadmine ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Selle objekti üleslaadimine ei ole toetatud",
    "Target folder does not exist any more" : "Sihtkausta pole enam olemas",
    "Operation is blocked by access control" : "Tegevus on blokeeritud ligipääsupiirangute poolt",
    "Error when assembling chunks, status code {status}" : "Tükkide kokkupanemise viga, staatuskood {status}",
    "Actions" : "Tegevused",
    "Rename" : "Nimeta ümber",
    "Move" : "Liiguta",
    "Copy" : "Kopeeri",
    "Choose target folder" : "Vali sihtkaust",
    "Edit locally" : "Muuda lokaalselt",
    "Open" : "Ava",
    "Disconnect storage" : "Ühenda andmehoidla lahti",
    "Leave this share" : "Lahku jaoskaustast",
    "Could not load info for file \"{file}\"" : "Faili \"{file}\" info laadimine ebaõnnestus",
    "Files" : "Failid",
    "Details" : "Üksikasjad",
    "Please select tag(s) to add to the selection" : "Palun vali sildid, mida valitutele lisada",
    "Apply tag(s) to selection" : "Rakenda sildid valitutele",
    "Select directory \"{dirName}\"" : "Vali kataloog \"{dirName}\"",
    "Select file \"{fileName}\"" : "Vali fail \"{fileName}\"",
    "Pending" : "Ootel",
    "Unable to determine date" : "Kuupäeva tuvastamine ebaõnnestus",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval, palun kontrolli logifaile või võta ühendust administraatoriga",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Could not move \"{file}\", target exists" : "\"{file}\" liigutamine ebaõnnestus, sihtfail on juba olemas",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "copy" : "koopia",
    "Could not copy \"{file}\", target exists" : "\"{file}\" kopeerimine ebaõnnestus, sihtfail on juba olemas",
    "Could not copy \"{file}\"" : "\"{file}\" kopeerimine ebaõnnestus",
    "Copied {origin} inside {destination}" : "{origin} kopeeritud kausta {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ja {nbfiles} teist faili kopeeritud kausta {destination}",
    "Failed to redirect to client" : "Kliendi ümbersuunamine ebaõnnestus",
    "{newName} already exists" : "{newName} on juba olemas",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" ümbernimetamine ebaõnnestus, seda pole enam olemas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on juba \"{dir}\" kaustas kasutusel. Palun vali teine nimi.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" ümbernimetamine ebaõnnestus",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "Could not create file \"{file}\" because it already exists" : "Faili \"{file}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not create folder \"{dir}\" because it already exists" : "Kausta \"{dir}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not fetch file details \"{file}\"" : "Faili \"{file}\" üksikasjade laadimine ebaõnnestus",
    "Error deleting file \"{fileName}\"." : "Tõrge faili \"{fileName}\" kustutamisel.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Teistest kaustadest ei leitud {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Teistest kaustadest otsimiseks sisesta rohkem kui kaks sümbolit",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "_including %n hidden_::_including %n hidden_" : ["sealhulgas %n peidetud","sealhulgas %n peidetud"],
    "You do not have permission to upload or create files here" : "Sul pole luba siia faile lisada ja üles laadida",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "New" : "Uus",
    "Select file range" : "Vali failivahemik",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} / {quota} kasutusel",
    "{used} used" : "{used} kasutusel",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "\"/\" is not allowed inside a file name." : "\"/\" pole failinimedes lubatud.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" pole lubatud failitüüp",
    "View in folder" : "Vaata kaustas",
    "Path" : "Asukoht",
    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
    "Favorited" : "Lemmikud",
    "Favorite" : "Lemmik",
    "New folder" : "Uus kaust",
    "Create new folder" : "Loo uus kaust",
    "Upload file" : "Laadi fail üles",
    "Recent" : "Hiljutised",
    "Not favorited" : "Lemmikuks lisamata",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "An error occurred while trying to update the tags" : "Siltide uuendamisel tekkis tõrge",
    "Added to favorites" : "Lemmikutesse lisatud",
    "Removed from favorites" : "Lemmikutest eemaldatud",
    "You added {file} to your favorites" : "Lisasid {file} lemmikutesse",
    "You removed {file} from your favorites" : "Eemaldasid {file} lemmikutest",
    "Favorites" : "Lemmikud",
    "File changes" : "Failimuudatused",
    "Created by {user}" : "Loodud kasutaja {user} poolt",
    "Changed by {user}" : "Muudetud kasutaja {user} poolt",
    "Deleted by {user}" : "Kustutatud kasutaja {user} poolt",
    "Restored by {user}" : "Taastatud kasutaja {user} poolt",
    "Renamed by {user}" : "Ümber nimetatud kasutaja {user} poolt",
    "Moved by {user}" : "Liigutatud kasutaja {user} poolt",
    "You created {file}" : "Sa lõid faili {file}",
    "You created an encrypted file in {file}" : "Sa lõid krüpteeritud faili {file}",
    "{user} created {file}" : "Kasutaja {user} lõi faili {file}",
    "{user} created an encrypted file in {file}" : "Kasutaja {user} lõi krüpteeritud faili {file}",
    "{file} was created in a public folder" : "{file} loodi avalikus kaustas",
    "You changed {file}" : "Sa muutsid faili {file}",
    "You changed an encrypted file in {file}" : "Sa muutsid krüpteeritud faili {file}",
    "{user} changed {file}" : "Kasutaja {user} muutis faili {file}",
    "{user} changed an encrypted file in {file}" : "Kasutaja {user} muutis krüpteeritud faili {file}",
    "You deleted {file}" : "Sa kustutasid faili {file}",
    "You deleted an encrypted file in {file}" : "Sa kustutasid krüpteeritud faili {file}",
    "{user} deleted {file}" : "Kasutaja {user} kustutas faili {file}",
    "{user} deleted an encrypted file in {file}" : "Kasutaja {user} kustutas krüpteeritud faili {file}",
    "You restored {file}" : "Sa taastasid faili {file}",
    "{user} restored {file}" : "Kasutaja {user} taastas faili {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Sa nimetasid faili {oldfile} (peidetud) ümber, uus nimi {newfile} (peidetud)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Sa nimetasid faili {oldfile} (peidetud) ümber, uus nimi {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Sa nimetasid faili {oldfile} ümber, uus nimi {newfile} (peidetud)",
    "You renamed {oldfile} to {newfile}" : "Sa nimetasid faili {oldfile} ümber, uus nimi {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "Kasutaja {user} nimetas faili {oldfile} (peidetud) ümber, uus nimi {newfile} (peidetud)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "Kasutaja {user} nimetas faili {oldfile} (peidetud) ümber, uus nimi {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "Kasutaja {user} nimetas faili {oldfile} ümber, uus nimi {newfile} (peidetud)",
    "{user} renamed {oldfile} to {newfile}" : "Kasutaja {user} nimetas faili {oldfile} ümber, uus nimi {newfile}",
    "You moved {oldfile} to {newfile}" : "Sa liigutasid faili: {oldfile} nüüd {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} liigutas faili: {oldfile} nüüd {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fail lisati su <strong>lemmikutesse</strong> või eemaldati sealt",
    "A file or folder has been <strong>changed</strong>" : "Fail või kaust on <strong>muudetud</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Lemmikuks märgitud faili või kausta on <strong>muudetud</strong>",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "Accept" : "Nõustu",
    "Reject" : "Keeldu",
    "in %s" : "kaustas %s",
    "File Management" : "Failihaldus",
    "Reload current directory" : "Värskenda jooksvat kataloogi",
    "Go to the \"{dir}\" directory" : "Mine kataloogi \"{dir}\"",
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "Folder name" : "Kausta nimi",
    "Download file {name}" : "Laadi fail {name} alla",
    "File not found" : "Faili ei leitud",
    "{usedQuotaByte} used" : "{usedQuotaByte} kasutusel",
    "{relative}% used" : "{relative}% kasutusel",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Create" : "Loo",
    "Change" : "Muuda",
    "New owner" : "Uus omanik",
    "Unknown error" : "Tundmatu viga",
    "Loading current folder" : "Jooksva kausta laadimine",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
    "Go to the previous folder" : "Mine eelmisesse kausta",
    "Go back" : "Mine tagasi",
    "Shared by link" : "Jagatud lingiga",
    "Shared" : "Jagatud",
    "Files settings" : "Failide seaded",
    "File cannot be accessed" : "Failile ligipääs puudub",
    "Show hidden files" : "Näita peidetud faile",
    "Additional settings" : "Lisaseaded",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Use this address to access your Files via WebDAV" : "Oma failidele WebDAV kaudu ligipääsemiseks kasuta seda aadressi",
    "WebDAV URL copied to clipboard" : "WebDAV URL kopeeritud lõikepuhvrisse",
    "Blank" : "Tühi",
    "Unable to create new file from template" : "Faili loomine mallist ebaõnnestus",
    "Delete permanently" : "Kustuta jäädavalt",
    "Cancel" : "Loobu",
    "Open folder {displayName}" : "Ava kaust {displayName}",
    "Filename" : "Faili nimi",
    "Unable to initialize the templates directory" : "Mallide kausta loomine ebaõnnestus",
    "Create new templates folder" : "Loo uus mallide kaust",
    "Templates" : "Mallid",
    "Some files could not be moved" : "Mõnda faili ei saanud liigutada",
    "No favorites yet" : "Lemmikuid veel pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
    "All files" : "Kõik failid",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületavad serveri poolt üleslaaditavatele failidele määratud maksimaalse suuruse.",
    "Text file" : "Tekstifail",
    "New text file.txt" : "Uus tekstifail.txt",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopeeri otselink (töötab ainult nende kasutajate jaoks, kelle on ligipääs sellele failile/kaustale)",
    "You can only favorite a single file or folder at a time" : "Korraga saab lemmikuks märkida ainult ühe faili või kausta",
    "This file has the tag {tag}" : "Sellel failil on silt {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Sellel failil on sildid {firstTags} and {lastTag}",
    "\"remote user\"" : "\"kaugkasutaja\"",
    "Open folder {name}" : "Ava kaust {name}",
    "Search for an account" : "Otsi kontot",
    "Choose" : "Vali",
    "No files or folders have been deleted yet" : "Faile ega kaustu pole veel kustutatud",
    "Set up templates folder" : "Seadista mallide kaust",
    "Shares" : "Jagamisi",
    "Shared with others" : "Teistega jagatud",
    "Shared with you" : "Sinuga jagatud",
    "Deleted shares" : "Kustutatud jagamised",
    "Pending shares" : "Ootel jagamised"
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-29.0.7.tgz: share/nextcloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "File could not be found" : "Faili ei leitud",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Laadi alla",
    "Delete" : "Kustuta",
    "Tags" : "Sildid",
    "Show list view" : "Näita loendivaadet",
    "Home" : "Kodu",
    "Close" : "Sulge",
    "Could not create folder \"{dir}\"" : "Kausta \"{dir}\" loomine ebaõnnestus",
    "This will stop your current uploads." : "See peatab praegused üleslaadimised.",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "Processing files …" : "Failide töötlemine …",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Target folder \"{dir}\" does not exist any more" : "Kausta \"{dir}\" pole enam olemas",
    "Not enough free space" : "Pole piisavalt vaba ruumi",
    "An unknown error has occurred" : "Tekkis tundmatu tõrge",
    "File could not be uploaded" : "Faili üleslaadimine ebaõnnestus",
    "Uploading …" : "Üleslaadmine ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Selle objekti üleslaadimine ei ole toetatud",
    "Target folder does not exist any more" : "Sihtkausta pole enam olemas",
    "Operation is blocked by access control" : "Tegevus on blokeeritud ligipääsupiirangute poolt",
    "Error when assembling chunks, status code {status}" : "Tükkide kokkupanemise viga, staatuskood {status}",
    "Actions" : "Tegevused",
    "Rename" : "Nimeta ümber",
    "Move" : "Liiguta",
    "Copy" : "Kopeeri",
    "Choose target folder" : "Vali sihtkaust",
    "Edit locally" : "Muuda lokaalselt",
    "Open" : "Ava",
    "Disconnect storage" : "Ühenda andmehoidla lahti",
    "Leave this share" : "Lahku jaoskaustast",
    "Could not load info for file \"{file}\"" : "Faili \"{file}\" info laadimine ebaõnnestus",
    "Files" : "Failid",
    "Details" : "Üksikasjad",
    "Please select tag(s) to add to the selection" : "Palun vali sildid, mida valitutele lisada",
    "Apply tag(s) to selection" : "Rakenda sildid valitutele",
    "Select directory \"{dirName}\"" : "Vali kataloog \"{dirName}\"",
    "Select file \"{fileName}\"" : "Vali fail \"{fileName}\"",
    "Pending" : "Ootel",
    "Unable to determine date" : "Kuupäeva tuvastamine ebaõnnestus",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval, palun kontrolli logifaile või võta ühendust administraatoriga",
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Could not move \"{file}\", target exists" : "\"{file}\" liigutamine ebaõnnestus, sihtfail on juba olemas",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "copy" : "koopia",
    "Could not copy \"{file}\", target exists" : "\"{file}\" kopeerimine ebaõnnestus, sihtfail on juba olemas",
    "Could not copy \"{file}\"" : "\"{file}\" kopeerimine ebaõnnestus",
    "Copied {origin} inside {destination}" : "{origin} kopeeritud kausta {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} ja {nbfiles} teist faili kopeeritud kausta {destination}",
    "Failed to redirect to client" : "Kliendi ümbersuunamine ebaõnnestus",
    "{newName} already exists" : "{newName} on juba olemas",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" ümbernimetamine ebaõnnestus, seda pole enam olemas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on juba \"{dir}\" kaustas kasutusel. Palun vali teine nimi.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" ümbernimetamine ebaõnnestus",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "Could not create file \"{file}\" because it already exists" : "Faili \"{file}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not create folder \"{dir}\" because it already exists" : "Kausta \"{dir}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not fetch file details \"{file}\"" : "Faili \"{file}\" üksikasjade laadimine ebaõnnestus",
    "Error deleting file \"{fileName}\"." : "Tõrge faili \"{fileName}\" kustutamisel.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Teistest kaustadest ei leitud {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Teistest kaustadest otsimiseks sisesta rohkem kui kaks sümbolit",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "_including %n hidden_::_including %n hidden_" : ["sealhulgas %n peidetud","sealhulgas %n peidetud"],
    "You do not have permission to upload or create files here" : "Sul pole luba siia faile lisada ja üles laadida",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "New" : "Uus",
    "Select file range" : "Vali failivahemik",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} / {quota} kasutusel",
    "{used} used" : "{used} kasutusel",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "\"/\" is not allowed inside a file name." : "\"/\" pole failinimedes lubatud.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" pole lubatud failitüüp",
    "View in folder" : "Vaata kaustas",
    "Path" : "Asukoht",
    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
    "Favorited" : "Lemmikud",
    "Favorite" : "Lemmik",
    "New folder" : "Uus kaust",
    "Create new folder" : "Loo uus kaust",
    "Upload file" : "Laadi fail üles",
    "Recent" : "Hiljutised",
    "Not favorited" : "Lemmikuks lisamata",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "An error occurred while trying to update the tags" : "Siltide uuendamisel tekkis tõrge",
    "Added to favorites" : "Lemmikutesse lisatud",
    "Removed from favorites" : "Lemmikutest eemaldatud",
    "You added {file} to your favorites" : "Lisasid {file} lemmikutesse",
    "You removed {file} from your favorites" : "Eemaldasid {file} lemmikutest",
    "Favorites" : "Lemmikud",
    "File changes" : "Failimuudatused",
    "Created by {user}" : "Loodud kasutaja {user} poolt",
    "Changed by {user}" : "Muudetud kasutaja {user} poolt",
    "Deleted by {user}" : "Kustutatud kasutaja {user} poolt",
    "Restored by {user}" : "Taastatud kasutaja {user} poolt",
    "Renamed by {user}" : "Ümber nimetatud kasutaja {user} poolt",
    "Moved by {user}" : "Liigutatud kasutaja {user} poolt",
    "You created {file}" : "Sa lõid faili {file}",
    "You created an encrypted file in {file}" : "Sa lõid krüpteeritud faili {file}",
    "{user} created {file}" : "Kasutaja {user} lõi faili {file}",
    "{user} created an encrypted file in {file}" : "Kasutaja {user} lõi krüpteeritud faili {file}",
    "{file} was created in a public folder" : "{file} loodi avalikus kaustas",
    "You changed {file}" : "Sa muutsid faili {file}",
    "You changed an encrypted file in {file}" : "Sa muutsid krüpteeritud faili {file}",
    "{user} changed {file}" : "Kasutaja {user} muutis faili {file}",
    "{user} changed an encrypted file in {file}" : "Kasutaja {user} muutis krüpteeritud faili {file}",
    "You deleted {file}" : "Sa kustutasid faili {file}",
    "You deleted an encrypted file in {file}" : "Sa kustutasid krüpteeritud faili {file}",
    "{user} deleted {file}" : "Kasutaja {user} kustutas faili {file}",
    "{user} deleted an encrypted file in {file}" : "Kasutaja {user} kustutas krüpteeritud faili {file}",
    "You restored {file}" : "Sa taastasid faili {file}",
    "{user} restored {file}" : "Kasutaja {user} taastas faili {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Sa nimetasid faili {oldfile} (peidetud) ümber, uus nimi {newfile} (peidetud)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Sa nimetasid faili {oldfile} (peidetud) ümber, uus nimi {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Sa nimetasid faili {oldfile} ümber, uus nimi {newfile} (peidetud)",
    "You renamed {oldfile} to {newfile}" : "Sa nimetasid faili {oldfile} ümber, uus nimi {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "Kasutaja {user} nimetas faili {oldfile} (peidetud) ümber, uus nimi {newfile} (peidetud)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "Kasutaja {user} nimetas faili {oldfile} (peidetud) ümber, uus nimi {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "Kasutaja {user} nimetas faili {oldfile} ümber, uus nimi {newfile} (peidetud)",
    "{user} renamed {oldfile} to {newfile}" : "Kasutaja {user} nimetas faili {oldfile} ümber, uus nimi {newfile}",
    "You moved {oldfile} to {newfile}" : "Sa liigutasid faili: {oldfile} nüüd {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} liigutas faili: {oldfile} nüüd {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Fail lisati su <strong>lemmikutesse</strong> või eemaldati sealt",
    "A file or folder has been <strong>changed</strong>" : "Fail või kaust on <strong>muudetud</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Lemmikuks märgitud faili või kausta on <strong>muudetud</strong>",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "Accept" : "Nõustu",
    "Reject" : "Keeldu",
    "in %s" : "kaustas %s",
    "File Management" : "Failihaldus",
    "Reload current directory" : "Värskenda jooksvat kataloogi",
    "Go to the \"{dir}\" directory" : "Mine kataloogi \"{dir}\"",
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "Filename" : "Faili nimi",
    "Folder name" : "Kausta nimi",
    "Type" : "Tüüp",
    "File not found" : "Faili ei leitud",
    "{usedQuotaByte} used" : "{usedQuotaByte} kasutusel",
    "{relative}% used" : "{relative}% kasutusel",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Create" : "Loo",
    "Submit" : "Saada",
    "Change" : "Muuda",
    "New owner" : "Uus omanik",
    "Unknown error" : "Tundmatu viga",
    "Loading current folder" : "Jooksva kausta laadimine",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
    "Go to the previous folder" : "Mine eelmisesse kausta",
    "Go back" : "Mine tagasi",
    "Shared by link" : "Jagatud lingiga",
    "Shared" : "Jagatud",
    "Views" : "Vaated",
    "Files settings" : "Failide seaded",
    "File cannot be accessed" : "Failile ligipääs puudub",
    "Show hidden files" : "Näita peidetud faile",
    "Additional settings" : "Lisaseaded",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Use this address to access your Files via WebDAV" : "Oma failidele WebDAV kaudu ligipääsemiseks kasuta seda aadressi",
    "WebDAV URL copied to clipboard" : "WebDAV URL kopeeritud lõikepuhvrisse",
    "Blank" : "Tühi",
    "Unable to create new file from template" : "Faili loomine mallist ebaõnnestus",
    "Delete permanently" : "Kustuta jäädavalt",
    "Cancel" : "Loobu",
    "Open folder {displayName}" : "Ava kaust {displayName}",
    "Today" : "Täna",
    "Audio" : "Helid",
    "Videos" : "Videod",
    "Unable to initialize the templates directory" : "Mallide kausta loomine ebaõnnestus",
    "Templates" : "Mallid",
    "Some files could not be moved" : "Mõnda faili ei saanud liigutada",
    "No favorites yet" : "Lemmikuid veel pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
    "All files" : "Kõik failid",
    "Personal Files" : "Isiklikud Failid",
    "No personal files found" : "Isiklikke faile ei leitud",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületavad serveri poolt üleslaaditavatele failidele määratud maksimaalse suuruse.",
    "Text file" : "Tekstifail",
    "New text file.txt" : "Uus tekstifail.txt",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopeeri otselink (töötab ainult nende kasutajate jaoks, kelle on ligipääs sellele failile/kaustale)",
    "\"remote user\"" : "\"kaugkasutaja\"",
    "Create new templates folder" : "Loo uus mallide kaust"
},
"nplurals=2; plural=(n != 1);");
